@@ -5,35 +5,38 @@
 //!
 //! There are currently only high-level abstractions for live visualisation, where
 //! it is consistently fed with data,
-//! 
+//!
 //! but mp3 or wav file abstractions might be added in the future.
 //!
-//! # Code Example with spectralizer
+//! # Code Example with spectrum
 //! ```
+//! // make sure to enable the `cpal` feature for audio capturing from system
 //! use audioviz::audio_capture::{config::Config as CaptureConfig, capture::Capture};
-//! use audioviz::spectralizer::stream::{Stream, StreamController};
-//! use audioviz::spectralizer::config::StreamConfig;
 //! 
-//! fn main() {
-//!     // captures audio from system using cpal
-//!     let capture = Capture::init(CaptureConfig::default());
-//! 
-//!     // continuous processing of data received from capture
-//!     let audio = Stream::init_with_capture(capture, StreamConfig::default());
-//!     let audio_controller: StreamController = audio.get_controller();
-//! 
-//!     loop {
-//!         // stored as Vec<`spectralizer::Frequency`>
-//!         let data = audio_controller.get_frequencies();
-//!         /*
-//!         do something with data ...
-//!         */
-//!     }
+//! use audioviz::spectrum::stream::{Stream, StreamController};
+//! use audioviz::spectrum::config::StreamConfig;
+//!
+//!
+//! // captures audio from system using cpal
+//! let capture = Capture::init(CaptureConfig::default())
+//!     .unwrap();
+//!
+//! // continuous processing of data received from capture
+//! let audio = Stream::init_with_capture(&capture, StreamConfig::default());
+//! let audio_controller: StreamController = audio.get_controller();
+//!
+//! loop {
+//!     // stored as Vec<`spectralizer::Frequency`>
+//!     let data = audio_controller.get_frequencies();
+//!     /*
+//!     do something with data ...
+//!     */
 //! }
+//!
 //! ```
 
 /// seperates continuous audio-data to vector of single frequencies
-pub mod spectralizer;
+pub mod spectrum;
 
 /// captures audio from system using cpal
 #[cfg(feature = "cpal")]
